@@ -1,7 +1,9 @@
 use crate::config::{OutputFormat, TracingTargetOption};
 use clap::{App, AppSettings, Arg};
+use std::str::FromStr;
 
 use crate::fetch::is_target_available;
+use crate::manifest::bare_version::BareVersion;
 
 pub mod id {
     pub const ARG_SEEK_PATH: &str = "seek_path";
@@ -15,6 +17,7 @@ pub mod id {
     pub const ARG_TOOLCHAIN_FILE: &str = "toolchain_file";
     pub const ARG_IGNORE_LOCKFILE: &str = "lockfile";
     pub const ARG_OUTPUT_FORMAT: &str = "output_format";
+    pub const ARG_NO_USER_OUTPUT: &str = "no_user_output";
     pub const ARG_VERIFY: &str = "verify_msrv";
     pub const ARG_RELEASE_SOURCE: &str = "release_source";
     pub const ARG_NO_LOG: &str = "no_log";
@@ -26,6 +29,9 @@ pub mod id {
     pub const SUB_COMMAND_LIST: &str = "list";
     pub const SUB_COMMAND_LIST_VARIANT: &str = "list_variant";
 
+    pub const SUB_COMMAND_SET: &str = "set";
+    pub const SUB_COMMAND_SET_VALUE: &str = "set_value";
+
     pub const SUB_COMMAND_SHOW: &str = "show";
 
     pub const SUB_COMMAND_VERIFY: &str = "verify";
@@ -48,6 +54,7 @@ used to validate whether a Rust toolchain version is compatible. The default `ch
 \"cargo build\". A custom `check` command should be runnable by rustup, as they will be passed on to \
 rustup like so: `rustup run <toolchain> <COMMAND...>`. You'll only need to provide the <COMMAND...> part.")
         .subcommand(list())
+        .subcommand(set())
         .subcommand(show())
         .subcommand(verify())
         .arg(
@@ -134,7 +141,16 @@ rustup like so: `rustup run <toolchain> <COMMAND...>`. You'll only need to provi
             .takes_value(true)
             .possible_values(OutputFormat::custom_formats())
             .long_help("Output status messages in machine-readable format. \
-        Machine-readable status updates will be printed in the requested format to stdout.")
+            Machine-readable status updates will be printed in the requested format to stdout. \
+            Ignored when used in conjunction with the `--no-user-output` flag.")
+        )
+        .arg(Arg::new(id::ARG_NO_USER_OUTPUT)
+            .long("no-user-output")
+            .help("Disables user output")
+            .long_help("Disables user output. Useful when when `--log-target stdout` is present, \
+            so no clipping between the user output prints and log message prints will take place. \
+            When present, the `--output-format [value]` option will be ignored.")
+            .takes_value(false)
         )
         .arg(Arg::new(id::ARG_VERIFY)
             .long("verify")
@@ -195,7 +211,7 @@ pub fn custom_check() -> Arg<'static> {
             "If given, this command is used to validate if a Rust version is \
                 compatible. Should be available to rustup, i.e. the command should work like \
                 so: `rustup run <toolchain> <COMMAND>`. \
-                The default check action is `cargo check --all`.",
+                The default check action is `cargo check`.",
         )
         .multiple_values(true)
         .takes_value(true)
@@ -217,9 +233,29 @@ pub fn list() -> App<'static> {
         )
 }
 
+pub fn set() -> App<'static> {
+    App::new(id::SUB_COMMAND_SET)
+        .arg(
+            Arg::new(id::SUB_COMMAND_SET_VALUE)
+                .help("The version to be set as MSRV")
+                .value_name("MSRV")
+                .takes_value(true)
+                .required(true)
+                .validator(BareVersion::from_str),
+        )
+        .about("Set the MSRV of the current crate to a given Rust version.")
+}
+
 pub fn show() -> App<'static> {
     App::new(id::SUB_COMMAND_SHOW)
         .about("Show the MSRV of your crate, as specified in the Cargo manifest.")
+        .after_help(
+            "The given version must be a two- or three component Rust version number. \
+                   MSRV values prior to Rust 1.56 will be written to the `package.metadata.msrv` field \
+                   in the Cargo manifest, \
+                   while MSRV's greater or equal to 1.56 will be written to `package.rust-version` \
+                   in the Cargo manifest.",
+        )
 }
 
 pub fn verify() -> App<'static> {
