@@ -3,12 +3,14 @@ use std::path::{Path, PathBuf};
 use toml_edit::{Document, Item};
 
 use crate::config::list::ListCmdConfig;
+use crate::config::set::SetCmdConfig;
 use clap::ArgMatches;
 use rust_releases::semver;
 
 use crate::errors::{CargoMSRVError, IoErrorSource, TResult};
 
 pub(crate) mod list;
+pub(crate) mod set;
 
 #[derive(Debug, Clone, Copy)]
 pub enum OutputFormat {
@@ -30,12 +32,23 @@ impl Default for OutputFormat {
 
 impl OutputFormat {
     pub const JSON: &'static str = "json";
-    pub const NONE: &'static str = "void";
 
     /// A set of formats which may be given as a configuration option
     ///   through the CLI.
     pub fn custom_formats() -> &'static [&'static str] {
-        &[Self::JSON, Self::NONE]
+        &[Self::JSON]
+    }
+
+    /// Parse the output format from the given `&str`.
+    ///
+    /// **Panics**
+    ///
+    /// Panics if the format is not known, or can not be set by a user.
+    pub fn from_custom_format_str(item: &str) -> Self {
+        match item {
+            Self::JSON => Self::Json,
+            _ => unreachable!(),
+        }
     }
 }
 
@@ -56,6 +69,8 @@ pub enum ModeIntent {
     List,
     // Verifies the given MSRV
     Verify,
+    // Set the MSRV in the Cargo manifest to a given value
+    Set,
     // Shows the MSRV of the current crate as specified in the Cargo manifest
     Show,
 }
@@ -66,6 +81,7 @@ impl From<ModeIntent> for &'static str {
             ModeIntent::Find => "determine-msrv",
             ModeIntent::List => "list-msrv",
             ModeIntent::Verify => "verify-msrv",
+            ModeIntent::Set => "set-msrv",
             ModeIntent::Show => "show-msrv",
         }
     }
@@ -145,7 +161,7 @@ impl<'a> Config<'a> {
         Self {
             mode_intent,
             target,
-            check_command: vec!["cargo", "check", "--all"],
+            check_command: vec!["cargo", "check"],
             crate_path: None,
             include_all_patch_releases: false,
             minimum_version: None,
@@ -341,6 +357,8 @@ impl<'config> TryFrom<&'config ArgMatches> for Config<'config> {
             ModeIntent::List
         } else if matches.subcommand_matches(id::SUB_COMMAND_SHOW).is_some() {
             ModeIntent::Show
+        } else if matches.subcommand_matches(id::SUB_COMMAND_SET).is_some() {
+            ModeIntent::Set
         } else if matches.subcommand_matches(id::SUB_COMMAND_VERIFY).is_some()
             || matches.is_present(id::ARG_VERIFY)
         {
@@ -425,14 +443,10 @@ impl<'config> TryFrom<&'config ArgMatches> for Config<'config> {
 
         builder = builder.ignore_lockfile(matches.is_present(id::ARG_IGNORE_LOCKFILE));
 
-        let output_format = matches.value_of(id::ARG_OUTPUT_FORMAT);
-        if let Some(output_format) = output_format {
-            let output_format = match output_format {
-                OutputFormat::JSON => OutputFormat::Json,
-                OutputFormat::NONE => OutputFormat::None,
-                _ => unreachable!(),
-            };
-
+        if matches.is_present(id::ARG_NO_USER_OUTPUT) {
+            builder = builder.output_format(OutputFormat::None);
+        } else if let Some(output_format) = matches.value_of(id::ARG_OUTPUT_FORMAT) {
+            let output_format = OutputFormat::from_custom_format_str(output_format);
             builder = builder.output_format(output_format);
         }
 
@@ -462,6 +476,9 @@ impl<'config> TryFrom<&'config ArgMatches> for Config<'config> {
         if let Some(cmd) = matches.subcommand_matches(id::SUB_COMMAND_LIST) {
             let cmd_config = ListCmdConfig::try_from(cmd)?;
             builder = builder.sub_command_config(SubCommandConfig::ListConfig(cmd_config));
+        } else if let Some(cmd) = matches.subcommand_matches(id::SUB_COMMAND_SET) {
+            let cmd_config = SetCmdConfig::try_from(cmd)?;
+            builder = builder.sub_command_config(SubCommandConfig::SetConfig(cmd_config));
         }
 
         Ok(builder.build())
@@ -513,11 +530,13 @@ macro_rules! as_sub_command_config {
 pub enum SubCommandConfig {
     None,
     ListConfig(ListCmdConfig),
+    SetConfig(SetCmdConfig),
     ShowConfig,
 }
 
 impl SubCommandConfig {
     as_sub_command_config!(list, ListConfig, ListCmdConfig);
+    as_sub_command_config!(set, SetConfig, SetCmdConfig);
 }
 
 #[derive(Debug, Clone)]
