@@ -126,6 +126,9 @@ pub enum IoErrorSource {
     #[error("Unable to determine current working directory")]
     CurrentDir,
 
+    #[error("Unable to open file '{0}'")]
+    OpenFile(PathBuf),
+
     #[error("Unable to read file '{0}'")]
     ReadFile(PathBuf),
 
